==> crm-commom-vo-1.1.9.11.release.jar: com/biz/crm/nebular/mdm/function/MdmFunctionReqVo.java <==
package com.biz.crm.nebular.mdm.function;
import com.biz.crm.nebular.mdm.CrmExtTenVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;
/**
 * 菜单表请求vo
 *
 * @author zxw
 * @date 2020-11-18 10:26:31
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "MdmFunctionReqVo", description = "菜单表")
public class MdmFunctionReqVo extends CrmExtTenVo {

    @ApiModelProperty("ID集合")
    private List<String> ids;

    @ApiModelProperty("菜单编码")
    private String functionCode;

    @ApiModelProperty("菜单编码集合")
    private List<String> functionCodeList;

    @ApiModelProperty("菜单名称")
    private String functionName;

    @ApiModelProperty("菜单排序")
    private String functionOrder;

    @ApiModelProperty("菜单地址")
    private String functionUrl;

    @ApiModelProperty("上级菜单编码")
    private String parentCode;

    @ApiModelProperty("图标")
    private String functionIcon;

    @ApiModelProperty("所属模块，1：mdm，2：dms，3：tpm，4：sfa")
    private String functionModule;

    @ApiModelProperty("菜单类型：0：系统菜单，1：dms商城，2：dms小程序，3:sfa小程序，4：sfaapp")
    private String functionConfig;

    private String functionLevel;

    @ApiModelProperty("角色编码")
    private String roleCode;

    @ApiModelProperty("是否允许页面配置 Y：是 N ：否 ")
    private String pageConfig;
    /**
     * 新增菜单配置字段  Y：是 N ：否
     * @date: 2020/12/17 16:09
     * @author: YuanZiJian
     */
    @ApiModelProperty("是否允许菜单配置 Y：是 N ：否 ")
    private String menuConfig;

    @ApiModelProperty("图标编码")
    private String iconCode;

    @ApiModelProperty("菜单显示模式:1显示0隐藏")
    private String functionVisible;

}

==> crm-commom-vo-1.1.9.31.release.jar: com/biz/crm/nebular/mdm/function/MdmFunctionReqVo.java <==
package com.biz.crm.nebular.mdm.function;
import com.biz.crm.nebular.mdm.CrmExtTenVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;
/**
 * 菜单表请求vo
 *
 * @author zxw
 * @date 2020-11-18 10:26:31
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "MdmFunctionReqVo", description = "菜单表")
public class MdmFunctionReqVo extends CrmExtTenVo {

    @ApiModelProperty("ID集合")
    private List<String> ids;

    @ApiModelProperty("菜单编码")
    private String functionCode;

    @ApiModelProperty("菜单编码集合")
    private List<String> functionCodeList;

    @ApiModelProperty("菜单名称")
    private String functionName;

    @ApiModelProperty("菜单排序")
    private String functionOrder;

    @ApiModelProperty("菜单地址")
    private String functionUrl;

    @ApiModelProperty("上级菜单编码")
    private String parentCode;

    @ApiModelProperty("图标")
    private String functionIcon;

    @ApiModelProperty("所属模块，1：mdm，2：dms，3：tpm，4：sfa")
    private String functionModule;

    @ApiModelProperty("菜单类型：0：系统菜单，1：dms商城，2：dms小程序，3:sfa小程序，4：sfaapp")
    private String functionConfig;

    private String functionLevel;

    @ApiModelProperty("角色编码")
    private String roleCode;

    @ApiModelProperty("是否允许页面配置 Y：是 N ：否 ")
    private String pageConfig;
    /**
     * 新增字段：是否可配置工作流字段  Y：是 N ：否
     * @date: 2020/12/17 16:09
     * @author: YuanZiJian
     */
    @ApiModelProperty("是否可配置工作流 Y：是 N ：否 ")
    private String menuConfig;

    @ApiModelProperty("图标编码")
    private String iconCode;

    @ApiModelProperty("菜单显示模式:1显示0隐藏")
    private String functionVisible;

}
